# mobile library

LEDBASE=/sys/class/leds
RESET_LEDDIR=${LEDBASE}/Mobile_RESETN
POWER_LEDDIR=${LEDBASE}/Mobile_Power
PWROFF_LEDDIR=${LEDBASE}/Mobile_PWRKEY_OFF
PWRON_LEDDIR=${LEDBASE}/Mobile_PWRKEY_ON
PWRKEY_LEDDIR=${LEDBASE}/Mobile_PWRKEY
KYM11_LEDDIR=${LEDBASE}/KYM1x_Power
USB_HUB_LEDDIR=${LEDBASE}/USB_Hub_Reset


# oneshot led
# led_shot(leddir, delay_on, wait)
function led_shot() {
    local leddir=$1
    local delay_on=$2
    local wait=$3

    if [ ! -e ${leddir} ]; then
        log "LED directory ${leddir} not exists."
        return
    fi

    if [ ! -e ${leddir}/shot ]; then
        echo "oneshot" > ${leddir}/trigger
    fi

    # setup delay_on time
    echo ${delay_on} > ${leddir}/delay_on
    echo 1 > ${leddir}/shot
    sleep ${wait}
}

# LED Off/On
function led_off_on() {
    local leddir=$1
    local time_off=$2

    if [ ! -e ${leddir} ]; then
        log "LED directory ${leddir} not exists."
        return
    fi

    echo 0 > ${leddir}/brightness
    sleep ${time_off}
    echo 1 > ${leddir}/brightness
}

function log() {
    local msg=$1
    logger -t mobile_reset $msg
    echo $msg
}

function detect_module() {
    local module="UNKNOWN"

    if [ -e /tmp/.amm570_found ]; then
        module="AMM570"
    elif [ -e /tmp/.aml574_found ]; then
        module="AML574A"
    elif [ -e /tmp/.bg96_found ]; then
        module="BG96"
    fi

    echo $module
}

function detect_module_by_id() {
    local xioid="0"
    local boardid="00"
    local module="UNKNOWN"

    for x in `cat /proc/cmdline`; do
        case $x in
        board_id=*)
            board_id="${x#board_id=}"
            ;;
        xio_id=*)
            xioid="${x#xio_id=}"
            ;;
        esac
    done

    case ${board_id}_${xioid} in
    # AML574A
    00_* )
        module="AML574A"
        ;;
    # BG96
    01_* )
        module="BG96"
        ;;
    esac

    echo $module
}
